/***************************************************************
 * Name:      leermodificar.cpp
 * Purpose:   Code for Dialog boxSizer
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-04-11
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "leermodificar.h"

BEGIN_EVENT_TABLE(leerModificar, wxDialog)
    EVT_TEXT(idTexto, leerModificar::OnModificado)
    EVT_CLOSE(leerModificar::OnClose)
    EVT_CONTEXT_MENU(leerModificar::OnContextMenu)
    EVT_MENU(idBorrar, leerModificar::OnBorrar)
    EVT_MENU(idCopiar, leerModificar::OnCopiar)
    EVT_MENU(idCortar, leerModificar::OnCortar)
    EVT_MENU(idPegar, leerModificar::OnPegar)
    EVT_MENU(idRedo, leerModificar::OnRedo)
    EVT_MENU(idUndo, leerModificar::OnUndo)
END_EVENT_TABLE()

leerModificar::leerModificar(wxWindow *wnd, datosTexto &datos)
    : wxDialog(wnd, -1, _T("Ejemplo edición de texto"))
{
    // Menú contextual
    menuContextual = new wxMenu();
    menuContextual->Append(idBorrar, _("&Limpiar"));
    menuContextual->Append(idCopiar, _("&Copiar\tCtl-C"));
    menuContextual->Append(idCortar, _("Co&rtar\tCtl-X"));
    menuContextual->Append(idPegar, _("&Pegar\tCtl-V"));
    menuContextual->Append(idRedo, _("&Redo\tCtl-Y"));
    menuContextual->Append(idUndo, _("&Undo\tCtl-Z"));

    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;
    wxTextValidator valTexto = wxTextValidator(wxFILTER_ALPHA | wxFILTER_SPACE, &datos.texto);

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    boxHorizontal->Add(new wxStaticText(this, wxID_ANY, _T("&Texto:")), wxSizerFlags().Border());
    ctrlTexto = new wxTextCtrl(this, idTexto, wxEmptyString, wxDefaultPosition, wxSize(200, wxDefaultCoord), 0, valTexto);
    boxHorizontal->Add(ctrlTexto, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    boxHorizontal->Add(new wxStaticText(this, wxID_ANY, _T("&Eco:")), wxSizerFlags().Border());
    ctrlRepetir = new wxTextCtrl(this, idRepetir, wxEmptyString, wxDefaultPosition, wxSize(200, wxDefaultCoord), wxTE_READONLY);
    boxHorizontal->Add(ctrlRepetir, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

void leerModificar::OnModificado(wxCommandEvent& event) {
    // Leer el contenido y mostrarlo en otro edit
    wxString contenido;

    contenido = ctrlTexto->GetValue();
//    ctrlRepetir->SetValue(contenido);
    ctrlRepetir->Clear();

    *ctrlRepetir << contenido;
}

void leerModificar::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void leerModificar::OnContextMenu(wxContextMenuEvent& event) {
    int id = event.GetId();
    activo = (wxTextCtrl*)this->FindWindow(id);
    if(!activo->IsKindOf(wxCLASSINFO(wxTextCtrl))) return;
    menuContextual->Enable(idBorrar, activo->IsEditable());
    menuContextual->Enable(idCopiar, activo->CanCopy());
    menuContextual->Enable(idCortar, activo->CanCut());
    menuContextual->Enable(idPegar, activo->CanPaste());
    menuContextual->Enable(idRedo, activo->IsEditable() && activo->CanRedo());
    menuContextual->Enable(idUndo, activo->IsEditable() && activo->CanUndo());
    PopupMenu(menuContextual);
}

void leerModificar::OnBorrar(wxCommandEvent &event) {
    activo->Clear();
}

void leerModificar::OnCopiar(wxCommandEvent &event) {
    activo->Copy();
}

void leerModificar::OnCortar(wxCommandEvent &event) {
    activo->Cut();
}

void leerModificar::OnPegar(wxCommandEvent &event) {
    activo->Paste();
}

void leerModificar::OnRedo(wxCommandEvent &event) {
    activo->Redo();
}

void leerModificar::OnUndo(wxCommandEvent &event) {
    activo->Undo();
}
